#
# Aura Engine (https://code.aura.radio/)
#
# Copyright (C) 2017-now() - The Aura Engine Team.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import json
import unittest
from datetime import datetime

from aura_engine.base.config import AuraConfig
from aura_steering_api.models.playout_program_entry import PlayoutProgramEntry
from aura_steering_api.types import UNSET


class TestApiSteering(unittest.TestCase):
    """
    Testing the Configuration.
    """

    config: AuraConfig
    mocked_steering_json = None

    def setUp(self):
        self.config = AuraConfig.instance.config
        with open("./tests/json/steering-api-v1-playout.json", "r") as file:
            self.mocked_steering_json = json.load(file)

    def test_api_steering_timeslot_model(self):
        print(self._testMethodName)
        print("Steering JSON: " + str(self.mocked_steering_json))

        timetable = self.mocked_steering_json

        self.assertIsNotNone(timetable)
        self.assertEqual(5, len(timetable))

        t1 = PlayoutProgramEntry.from_dict(timetable[0])
        start = datetime.strptime("2024-07-25T18:00:10", "%Y-%m-%dT%H:%M:%S")
        end = datetime.strptime("2024-07-25T19:00:00", "%Y-%m-%dT%H:%M:%S")
        # self.assertEqual(f"{start}...{end}", t1.id)
        self.assertEqual(start, t1.start)
        self.assertEqual(end, t1.end)
        self.assertEqual("Show 1", t1.show.name)
        self.assertEqual(9, t1.schedule.id)
        self.assertEqual(18, t1.timeslot.repetition_of_id)
        self.assertEqual(1, t1.playlist_id)
        # self.assertEqual(None, t1.schedule.default_playlist_id)
        self.assertEqual(1, t1.show.default_playlist_id)
        self.assertEqual(1, t1.show.id)

    def test_api_steering_current_timeslot_model(self):
        """
        Test deserializing current steering timeslot model.
        """
        with open("./tests/json/steering-api-v1-program-playout.json", "r") as file:
            playout_json = json.load(file)
            for obj in playout_json:
                t = PlayoutProgramEntry.from_dict(obj)


if __name__ == "__main__":
    unittest.main()
